@@ -432,12 +432,7 @@ cluscata <- function(Data, nblo, NameBlocks = NULL, NameVar = NULL, Noise_cluste
 
         # multiple threshold
         if (Unique_threshold == FALSE) {
-          grou <- NULL
-          for (i in 1:nblo)
-          {
-            grou[i] <- which.max(cr[[i]])
-          }
-
+          grou=coupe
 
           mat_utile <- matrix(unlist(cr2), nrow = nblo, ncol = 2, byrow = TRUE)
 
