@@ -1,9 +1,7 @@
-##=============================================================================
+## =============================================================================
 
 
-##' @title Displays the STATIS graphs
-##'
-##'
+##' @title Display the STATIS charts
 ##' @usage
 ##' \method{plot}{statis}(x, axes=c(1,2), Graph_obj=TRUE,
 ##' Graph_weights=TRUE, Graph_eig=TRUE, tit="STATIS", col=NULL, cex=1, font=1,
@@ -56,75 +54,64 @@
 ##'
 ##' @export
 
-##=============================================================================
+## =============================================================================
 
 
 
-plot.statis=function(x, axes=c(1,2), Graph_obj=TRUE, Graph_weights=TRUE, Graph_eig=TRUE,
-                     tit="STATIS", col=NULL, cex=1, font=1, xlim=NULL, ylim=NULL, ...)
-{
-
-  res.statis=x
-  if(inherits(res.statis, "statis")==FALSE)
-  {
+plot.statis <- function(x, axes = c(1, 2), Graph_obj = TRUE, Graph_weights = TRUE, Graph_eig = TRUE,
+                        tit = "STATIS", col = NULL, cex = 1, font = 1, xlim = NULL, ylim = NULL, ...) {
+  res.statis <- x
+  if (inherits(res.statis, "statis") == FALSE) {
     stop("The class of the object must be 'statis'")
   }
 
-  if(Graph_obj==TRUE)
-  {
-    #show graphical representation
-    C=res.statis$coord
-    if(is.null(col)==TRUE)
-    {
-      col=rainbow(nrow(C))
+  if (Graph_obj == TRUE) {
+    # show graphical representation
+    C <- res.statis$coord
+    if (is.null(col) == TRUE) {
+      col <- rainbow(nrow(C))
     }
-    vp=res.statis$eigenvalues
-    if (Graph_eig==TRUE)
-    {
+    vp <- res.statis$eigenvalues
+    if (Graph_eig == TRUE) {
       dev.new()
-      barplot(vp, col="blue", main="Eigenvalues")
+      barplot(vp, col = "blue", main = "Eigenvalues")
     }
-    pouriner=res.statis$inertia
-    un=axes[1]
-    deux=axes[2]
-    if(is.null(xlim)==TRUE)
-    {
-      xlim=c(min(C[,un])-0.2,max(C[,un])+0.2)
+    pouriner <- res.statis$inertia
+    un <- axes[1]
+    deux <- axes[2]
+    if (is.null(xlim) == TRUE) {
+      xlim <- c(min(C[, un]) - 0.2, max(C[, un]) + 0.2)
     }
-    if(is.null(ylim)==TRUE)
-    {
-      ylim=c(min(C[,deux])-0.2,max(C[,deux])+0.2)
+    if (is.null(ylim) == TRUE) {
+      ylim <- c(min(C[, deux]) - 0.2, max(C[, deux]) + 0.2)
     }
     dev.new()
-    plot(C[,un],C[,deux],type="n",lwd=5,pch=16,xlab=paste("Dim",axes[1], "(" ,pouriner[un],"%)"), ylab=paste("Dim",axes[2], "(" ,pouriner[deux],"%)"), xlim=xlim, ylim=ylim)
-    text(C[,un],C[,deux],rownames(C),col=col, cex=cex, font=font)
-    abline(h=0,v=0)
+    plot(C[, un], C[, deux], type = "n", lwd = 5, pch = 16, xlab = paste("Dim", axes[1], "(", pouriner[un], "%)"), ylab = paste("Dim", axes[2], "(", pouriner[deux], "%)"), xlim = xlim, ylim = ylim)
+    text(C[, un], C[, deux], rownames(C), col = col, cex = cex, font = font)
+    abline(h = 0, v = 0)
     title(tit)
 
 
-    #projection of each object of each block
+    # projection of each object of each block
 
     dev.new()
-    n=res.statis$param$n
-    nblo=res.statis$param$nblo
-    configs=res.statis$proj_config
-    plot(C[,un],C[,deux],type="n",lwd=5,pch=16,xlab=paste("Dim",axes[1], "(" ,pouriner[un],"%)"), ylab=paste("Dim",axes[2], "(" ,pouriner[deux],"%)"),xlim=c(min(C[,un])-0.25,max(C[,un])+0.25), ylim=c(min(C[,deux])-0.25,max(C[,deux])+0.25))
-    text(C[,un],C[,deux],rownames(C),col=rainbow(n),font=2)
+    n <- res.statis$param$n
+    nblo <- res.statis$param$nblo
+    configs <- res.statis$proj_config
+    plot(C[, un], C[, deux], type = "n", lwd = 5, pch = 16, xlab = paste("Dim", axes[1], "(", pouriner[un], "%)"), ylab = paste("Dim", axes[2], "(", pouriner[deux], "%)"), xlim = c(min(C[, un]) - 0.25, max(C[, un]) + 0.25), ylim = c(min(C[, deux]) - 0.25, max(C[, deux]) + 0.25))
+    text(C[, un], C[, deux], rownames(C), col = rainbow(n), font = 2)
     for (l in 1:nblo)
     {
-      points(configs[,un,l],configs[,deux,l],col=rainbow(n),pch=20)
-      arrows(C[,un],C[,deux],configs[,un,l],configs[,deux,l],col=rainbow(n),lwd=0.5,lty = 2,angle=0)
+      points(configs[, un, l], configs[, deux, l], col = rainbow(n), pch = 20)
+      arrows(C[, un], C[, deux], configs[, un, l], configs[, deux, l], col = rainbow(n), lwd = 0.5, lty = 2, angle = 0)
     }
-    abline(h=0,v=0)
+    abline(h = 0, v = 0)
     title(tit)
   }
 
-  if (Graph_weights==TRUE)
-  {
+  if (Graph_weights == TRUE) {
     dev.new()
     barplot(res.statis$weights)
     title(paste("Weights"))
   }
-
-
 }
